import{s as we,n as ye,o as be}from"../chunks/scheduler.c59d9fbb.js";import{S as ge,i as _e,g as i,s as l,r as he,A as Ae,h as o,f as t,c as r,j as P,u as me,x as s,k as d,y as c,a as n,v as fe,d as ce,t as ue,w as pe}from"../chunks/index.a47918e3.js";import{I as ve}from"../chunks/IconCopyLink.1678bef0.js";function xe(K){let h,H,m,u,$,v,G,k,Q="IA3",E,w,V=`This conceptual guide gives a brief overview of <a href="https://arxiv.org/abs/2205.05638" rel="nofollow">IA3</a>, a parameter-efficient fine tuning technique that is
intended to improve over <a href="./lora">LoRA</a>.`,S,y,X=`To make fine-tuning more efficient, IA3 (Infused Adapter by Inhibiting and Amplifying Inner Activations)
rescales inner activations with learned vectors. These learned vectors are injected in the attention and feedforward modules
in a typical transformer-based architecture. These learned vectors are the only trainable parameters during fine-tuning, and thus the original
weights remain frozen. Dealing with learned vectors (as opposed to learned low-rank updates to a weight matrix like LoRA)
keeps the number of trainable parameters much smaller.`,j,b,Y="Being similar to LoRA, IA3 carries many of the same advantages:",F,g,Z="<li>IA3 makes fine-tuning more efficient by drastically reducing the number of trainable parameters. (For T0, an IA3 model only has about 0.01% trainable parameters, while even LoRA has &gt; 0.1%)</li> <li>The original pre-trained weights are kept frozen, which means you can have multiple lightweight and portable IA3 models for various downstream tasks built on top of them.</li> <li>Performance of models fine-tuned using IA3 is comparable to the performance of fully fine-tuned models.</li> <li>IA3 does not add any inference latency because adapter weights can be merged with the base model.</li>",N,_,ee=`In principle, IA3 can be applied to any subset of weight matrices in a neural network to reduce the number of trainable
parameters. Following the authors’ implementation, IA3 weights are added to the key, value and feedforward layers
of a Transformer model. Given the target layers for injecting IA3 parameters, the number of trainable parameters
can be determined based on the size of the weight matrices.`,R,f,p,M,A,J,L,te="Common IA3 parameters in PEFT",z,x,ae="As with other methods supported by PEFT, to fine-tune a model using IA3, you need to:",q,C,ne="<li>Instantiate a base model.</li> <li>Create a configuration (<code>IA3Config</code>) where you define IA3-specific parameters.</li> <li>Wrap the base model with <code>get_peft_model()</code> to get a trainable <code>PeftModel</code>.</li> <li>Train the <code>PeftModel</code> as you normally would train the base model.</li>",U,I,ie="<code>IA3Config</code> allows you to control how IA3 is applied to the base model through the following parameters:",O,T,oe=`<li><code>target_modules</code>: The modules (for example, attention blocks) to apply the IA3 vectors.</li> <li><code>feedforward_modules</code>: The list of modules to be treated as feedforward layers in <code>target_modules</code>. While learned vectors are multiplied with
the output activation for attention blocks, the vectors are multiplied with the input for classic feedforward layers.</li> <li><code>modules_to_save</code>: List of modules apart from IA3 layers to be set as trainable and saved in the final checkpoint. These typically include model’s custom head that is randomly initialized for the fine-tuning task.</li>`,W;return v=new ve({}),A=new ve({}),{c(){h=i("meta"),H=l(),m=i("h1"),u=i("a"),$=i("span"),he(v.$$.fragment),G=l(),k=i("span"),k.textContent=Q,E=l(),w=i("p"),w.innerHTML=V,S=l(),y=i("p"),y.textContent=X,j=l(),b=i("p"),b.textContent=Y,F=l(),g=i("ul"),g.innerHTML=Z,N=l(),_=i("p"),_.textContent=ee,R=l(),f=i("h2"),p=i("a"),M=i("span"),he(A.$$.fragment),J=l(),L=i("span"),L.textContent=te,z=l(),x=i("p"),x.textContent=ae,q=l(),C=i("ol"),C.innerHTML=ne,U=l(),I=i("p"),I.innerHTML=ie,O=l(),T=i("ul"),T.innerHTML=oe,this.h()},l(e){const a=Ae("svelte-1phssyn",document.head);h=o(a,"META",{name:!0,content:!0}),a.forEach(t),H=r(e),m=o(e,"H1",{class:!0});var B=P(m);u=o(B,"A",{id:!0,class:!0,href:!0});var le=P(u);$=o(le,"SPAN",{});var re=P($);me(v.$$.fragment,re),re.forEach(t),le.forEach(t),G=r(B),k=o(B,"SPAN",{"data-svelte-h":!0}),s(k)!=="svelte-1jlt2fa"&&(k.textContent=Q),B.forEach(t),E=r(e),w=o(e,"P",{"data-svelte-h":!0}),s(w)!=="svelte-1f08nkr"&&(w.innerHTML=V),S=r(e),y=o(e,"P",{"data-svelte-h":!0}),s(y)!=="svelte-iyuejo"&&(y.textContent=X),j=r(e),b=o(e,"P",{"data-svelte-h":!0}),s(b)!=="svelte-mvs6w2"&&(b.textContent=Y),F=r(e),g=o(e,"UL",{"data-svelte-h":!0}),s(g)!=="svelte-1d130bu"&&(g.innerHTML=Z),N=r(e),_=o(e,"P",{"data-svelte-h":!0}),s(_)!=="svelte-4d6y4h"&&(_.textContent=ee),R=r(e),f=o(e,"H2",{class:!0});var D=P(f);p=o(D,"A",{id:!0,class:!0,href:!0});var se=P(p);M=o(se,"SPAN",{});var de=P(M);me(A.$$.fragment,de),de.forEach(t),se.forEach(t),J=r(D),L=o(D,"SPAN",{"data-svelte-h":!0}),s(L)!=="svelte-1cr5j59"&&(L.textContent=te),D.forEach(t),z=r(e),x=o(e,"P",{"data-svelte-h":!0}),s(x)!=="svelte-16q36ht"&&(x.textContent=ae),q=r(e),C=o(e,"OL",{"data-svelte-h":!0}),s(C)!=="svelte-1sklxcv"&&(C.innerHTML=ne),U=r(e),I=o(e,"P",{"data-svelte-h":!0}),s(I)!=="svelte-1ufth76"&&(I.innerHTML=ie),O=r(e),T=o(e,"UL",{"data-svelte-h":!0}),s(T)!=="svelte-14h3vsi"&&(T.innerHTML=oe),this.h()},h(){d(h,"name","hf:doc:metadata"),d(h,"content",JSON.stringify(Ce)),d(u,"id","ia3"),d(u,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),d(u,"href","#ia3"),d(m,"class","relative group"),d(p,"id","common-ia3-parameters-in-peft"),d(p,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),d(p,"href","#common-ia3-parameters-in-peft"),d(f,"class","relative group")},m(e,a){c(document.head,h),n(e,H,a),n(e,m,a),c(m,u),c(u,$),fe(v,$,null),c(m,G),c(m,k),n(e,E,a),n(e,w,a),n(e,S,a),n(e,y,a),n(e,j,a),n(e,b,a),n(e,F,a),n(e,g,a),n(e,N,a),n(e,_,a),n(e,R,a),n(e,f,a),c(f,p),c(p,M),fe(A,M,null),c(f,J),c(f,L),n(e,z,a),n(e,x,a),n(e,q,a),n(e,C,a),n(e,U,a),n(e,I,a),n(e,O,a),n(e,T,a),W=!0},p:ye,i(e){W||(ce(v.$$.fragment,e),ce(A.$$.fragment,e),W=!0)},o(e){ue(v.$$.fragment,e),ue(A.$$.fragment,e),W=!1},d(e){e&&(t(H),t(m),t(E),t(w),t(S),t(y),t(j),t(b),t(F),t(g),t(N),t(_),t(R),t(f),t(z),t(x),t(q),t(C),t(U),t(I),t(O),t(T)),t(h),pe(v),pe(A)}}}const Ce={local:"ia3",sections:[{local:"common-ia3-parameters-in-peft",title:"Common IA3 parameters in PEFT"}],title:"IA3 "};function Ie(K){return be(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class Pe extends ge{constructor(h){super(),_e(this,h,Ie,xe,we,{})}}export{Pe as component};
