import{s as kt,n as _t,o as bt}from"../chunks/scheduler.c59d9fbb.js";import{S as Tt,i as Ct,g as i,s as r,r as He,A as Pt,h as s,f as t,c as l,j as m,u as ze,x as o,k as p,y as u,a,v as Ae,d as qe,t as Ee,w as Se}from"../chunks/index.a47918e3.js";import{I as Ne}from"../chunks/IconCopyLink.1678bef0.js";function Lt(De){let h,ee,f,v,Q,T,je,R,Ge="Prompting",te,C,Oe="Training large pretrained language models is very time-consuming and compute-intensive. As they continue to grow in size, there is increasing interest in more efficient training methods such as <em>prompting</em>. Prompting primes a frozen pretrained model for a specific downstream task by including a text prompt that describes the task or even demonstrates an example of the task. With prompting, you can avoid fully training a separate model for each downstream task, and use the same frozen pretrained model instead. This is a lot easier because you can use the same model for several different tasks, and it is significantly more efficient to train and store a smaller set of prompt parameters than to train all the model’s parameters.",ne,P,Ve="There are two categories of prompting methods:",ae,L,Be="<li>hard prompts are manually handcrafted text prompts with discrete input tokens; the downside is that it requires a lot of effort to create a good prompt</li> <li>soft prompts are learnable tensors concatenated with the input embeddings that can be optimized to a dataset; the downside is that they aren’t human readable because you aren’t matching these “virtual tokens” to the embeddings of a real word</li>",ie,M,Re="This conceptual guide provides a brief overview of the soft prompt methods included in 🤗 PEFT: prompt tuning, prefix tuning, and P-tuning.",se,d,x,X,$,Ie,J,Je="Prompt tuning",re,y,We='<img src="https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/peft/prompt-tuning.png"/>',le,H,Ke='Only train and store a significantly smaller set of task-specific prompt parameters <a href="https://arxiv.org/abs/2104.08691">(image source)</a>.',oe,z,Qe="Prompt tuning was developed for text classification tasks on T5 models, and all downstream tasks are cast as a text generation task. For example, sequence classification usually assigns a single class label to a sequence of text. By casting it as a text generation task, the tokens that make up the class label are <em>generated</em>. Prompts are added to the input as a series of tokens. Typically, the model parameters are fixed which means the prompt tokens are also fixed by the model parameters.",pe,A,Xe="The key idea behind prompt tuning is that prompt tokens have their own parameters that are updated independently. This means you can keep the pretrained model’s parameters frozen, and only update the gradients of the prompt token embeddings. The results are comparable to the traditional method of training the entire model, and prompt tuning performance scales as model size increases.",ue,q,Ye='Take a look at <a href="../task_guides/clm-prompt-tuning">Prompt tuning for causal language modeling</a> for a step-by-step guide on how to train a model with prompt tuning.',me,c,w,Y,E,Fe,W,Ze="Prefix tuning",he,k,et='<img src="https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/peft/prefix-tuning.png"/>',fe,S,tt='Optimize the prefix parameters for each task <a href="https://arxiv.org/abs/2101.00190">(image source)</a>.',de,N,nt="Prefix tuning was designed for natural language generation (NLG) tasks on GPT models. It is very similar to prompt tuning; prefix tuning also prepends a sequence of task-specific vectors to the input that can be trained and updated while keeping the rest of the pretrained model’s parameters frozen.",ce,j,at="The main difference is that the prefix parameters are inserted in <strong>all</strong> of the model layers, whereas prompt tuning only adds the prompt parameters to the model input embeddings. The prefix parameters are also optimized by a separate feed-forward network (FFN) instead of training directly on the soft prompts because it causes instability and hurts performance. The FFN is discarded after updating the soft prompts.",ge,I,it="As a result, the authors found that prefix tuning demonstrates comparable performance to fully finetuning a model, despite having 1000x fewer parameters, and it performs even better in low-data settings.",ve,F,st='Take a look at <a href="../task_guides/seq2seq-prefix-tuning">Prefix tuning for conditional generation</a> for a step-by-step guide on how to train a model with prefix tuning.',xe,g,_,Z,U,Ue,K,rt="P-tuning",ye,b,lt='<img src="https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/peft/p-tuning.png"/>',we,D,ot='Prompt tokens can be inserted anywhere in the input sequence, and they are optimized by a prompt encoder <a href="https://arxiv.org/abs/2103.10385">(image source)</a>.',ke,G,pt=`P-tuning is designed for natural language understanding (NLU) tasks and all language models.
It is another variation of a soft prompt method; P-tuning also adds a trainable embedding tensor that can be optimized to find better prompts, and it uses a prompt encoder (a bidirectional long-short term memory network or LSTM) to optimize the prompt parameters. Unlike prefix tuning though:`,_e,O,ut="<li>the prompt tokens can be inserted anywhere in the input sequence, and it isn’t restricted to only the beginning</li> <li>the prompt tokens are only added to the input instead of adding them to every layer of the model</li> <li>introducing <em>anchor</em> tokens can improve performance because they indicate characteristics of a component in the input sequence</li>",be,V,mt="The results suggest that P-tuning is more efficient than manually crafting prompts, and it enables GPT-like models to compete with BERT-like models on NLU tasks.",Te,B,ht='Take a look at <a href="../task_guides/ptuning-seq-classification">P-tuning for sequence classification</a> for a step-by-step guide on how to train a model with P-tuning.',Ce;return T=new Ne({}),$=new Ne({}),E=new Ne({}),U=new Ne({}),{c(){h=i("meta"),ee=r(),f=i("h1"),v=i("a"),Q=i("span"),He(T.$$.fragment),je=r(),R=i("span"),R.textContent=Ge,te=r(),C=i("p"),C.innerHTML=Oe,ne=r(),P=i("p"),P.textContent=Ve,ae=r(),L=i("ul"),L.innerHTML=Be,ie=r(),M=i("p"),M.textContent=Re,se=r(),d=i("h2"),x=i("a"),X=i("span"),He($.$$.fragment),Ie=r(),J=i("span"),J.textContent=Je,re=r(),y=i("div"),y.innerHTML=We,le=r(),H=i("small"),H.innerHTML=Ke,oe=r(),z=i("p"),z.innerHTML=Qe,pe=r(),A=i("p"),A.textContent=Xe,ue=r(),q=i("p"),q.innerHTML=Ye,me=r(),c=i("h2"),w=i("a"),Y=i("span"),He(E.$$.fragment),Fe=r(),W=i("span"),W.textContent=Ze,he=r(),k=i("div"),k.innerHTML=et,fe=r(),S=i("small"),S.innerHTML=tt,de=r(),N=i("p"),N.textContent=nt,ce=r(),j=i("p"),j.innerHTML=at,ge=r(),I=i("p"),I.textContent=it,ve=r(),F=i("p"),F.innerHTML=st,xe=r(),g=i("h2"),_=i("a"),Z=i("span"),He(U.$$.fragment),Ue=r(),K=i("span"),K.textContent=rt,ye=r(),b=i("div"),b.innerHTML=lt,we=r(),D=i("small"),D.innerHTML=ot,ke=r(),G=i("p"),G.textContent=pt,_e=r(),O=i("ul"),O.innerHTML=ut,be=r(),V=i("p"),V.textContent=mt,Te=r(),B=i("p"),B.innerHTML=ht,this.h()},l(e){const n=Pt("svelte-1phssyn",document.head);h=s(n,"META",{name:!0,content:!0}),n.forEach(t),ee=l(e),f=s(e,"H1",{class:!0});var Pe=m(f);v=s(Pe,"A",{id:!0,class:!0,href:!0});var ft=m(v);Q=s(ft,"SPAN",{});var dt=m(Q);ze(T.$$.fragment,dt),dt.forEach(t),ft.forEach(t),je=l(Pe),R=s(Pe,"SPAN",{"data-svelte-h":!0}),o(R)!=="svelte-t12lx5"&&(R.textContent=Ge),Pe.forEach(t),te=l(e),C=s(e,"P",{"data-svelte-h":!0}),o(C)!=="svelte-1hcip3m"&&(C.innerHTML=Oe),ne=l(e),P=s(e,"P",{"data-svelte-h":!0}),o(P)!=="svelte-xiexj5"&&(P.textContent=Ve),ae=l(e),L=s(e,"UL",{"data-svelte-h":!0}),o(L)!=="svelte-1gvlyfh"&&(L.innerHTML=Be),ie=l(e),M=s(e,"P",{"data-svelte-h":!0}),o(M)!=="svelte-b3zkga"&&(M.textContent=Re),se=l(e),d=s(e,"H2",{class:!0});var Le=m(d);x=s(Le,"A",{id:!0,class:!0,href:!0});var ct=m(x);X=s(ct,"SPAN",{});var gt=m(X);ze($.$$.fragment,gt),gt.forEach(t),ct.forEach(t),Ie=l(Le),J=s(Le,"SPAN",{"data-svelte-h":!0}),o(J)!=="svelte-ngjqp0"&&(J.textContent=Je),Le.forEach(t),re=l(e),y=s(e,"DIV",{class:!0,"data-svelte-h":!0}),o(y)!=="svelte-qr8fvs"&&(y.innerHTML=We),le=l(e),H=s(e,"SMALL",{"data-svelte-h":!0}),o(H)!=="svelte-uewnrm"&&(H.innerHTML=Ke),oe=l(e),z=s(e,"P",{"data-svelte-h":!0}),o(z)!=="svelte-76fon6"&&(z.innerHTML=Qe),pe=l(e),A=s(e,"P",{"data-svelte-h":!0}),o(A)!=="svelte-1jdd570"&&(A.textContent=Xe),ue=l(e),q=s(e,"P",{"data-svelte-h":!0}),o(q)!=="svelte-4a8ovt"&&(q.innerHTML=Ye),me=l(e),c=s(e,"H2",{class:!0});var Me=m(c);w=s(Me,"A",{id:!0,class:!0,href:!0});var vt=m(w);Y=s(vt,"SPAN",{});var xt=m(Y);ze(E.$$.fragment,xt),xt.forEach(t),vt.forEach(t),Fe=l(Me),W=s(Me,"SPAN",{"data-svelte-h":!0}),o(W)!=="svelte-1awvzrq"&&(W.textContent=Ze),Me.forEach(t),he=l(e),k=s(e,"DIV",{class:!0,"data-svelte-h":!0}),o(k)!=="svelte-fdff7q"&&(k.innerHTML=et),fe=l(e),S=s(e,"SMALL",{"data-svelte-h":!0}),o(S)!=="svelte-47ftky"&&(S.innerHTML=tt),de=l(e),N=s(e,"P",{"data-svelte-h":!0}),o(N)!=="svelte-p0gxj"&&(N.textContent=nt),ce=l(e),j=s(e,"P",{"data-svelte-h":!0}),o(j)!=="svelte-4rpf62"&&(j.innerHTML=at),ge=l(e),I=s(e,"P",{"data-svelte-h":!0}),o(I)!=="svelte-rleo2"&&(I.textContent=it),ve=l(e),F=s(e,"P",{"data-svelte-h":!0}),o(F)!=="svelte-pl8an9"&&(F.innerHTML=st),xe=l(e),g=s(e,"H2",{class:!0});var $e=m(g);_=s($e,"A",{id:!0,class:!0,href:!0});var yt=m(_);Z=s(yt,"SPAN",{});var wt=m(Z);ze(U.$$.fragment,wt),wt.forEach(t),yt.forEach(t),Ue=l($e),K=s($e,"SPAN",{"data-svelte-h":!0}),o(K)!=="svelte-17qubkz"&&(K.textContent=rt),$e.forEach(t),ye=l(e),b=s(e,"DIV",{class:!0,"data-svelte-h":!0}),o(b)!=="svelte-vgzrsg"&&(b.innerHTML=lt),we=l(e),D=s(e,"SMALL",{"data-svelte-h":!0}),o(D)!=="svelte-d3od69"&&(D.innerHTML=ot),ke=l(e),G=s(e,"P",{"data-svelte-h":!0}),o(G)!=="svelte-zzngku"&&(G.textContent=pt),_e=l(e),O=s(e,"UL",{"data-svelte-h":!0}),o(O)!=="svelte-1v13wiw"&&(O.innerHTML=ut),be=l(e),V=s(e,"P",{"data-svelte-h":!0}),o(V)!=="svelte-rvu4kt"&&(V.textContent=mt),Te=l(e),B=s(e,"P",{"data-svelte-h":!0}),o(B)!=="svelte-1dxbqez"&&(B.innerHTML=ht),this.h()},h(){p(h,"name","hf:doc:metadata"),p(h,"content",JSON.stringify(Mt)),p(v,"id","prompting"),p(v,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),p(v,"href","#prompting"),p(f,"class","relative group"),p(x,"id","prompt-tuning"),p(x,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),p(x,"href","#prompt-tuning"),p(d,"class","relative group"),p(y,"class","flex justify-center"),p(w,"id","prefix-tuning"),p(w,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),p(w,"href","#prefix-tuning"),p(c,"class","relative group"),p(k,"class","flex justify-center"),p(_,"id","ptuning"),p(_,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),p(_,"href","#ptuning"),p(g,"class","relative group"),p(b,"class","flex justify-center")},m(e,n){u(document.head,h),a(e,ee,n),a(e,f,n),u(f,v),u(v,Q),Ae(T,Q,null),u(f,je),u(f,R),a(e,te,n),a(e,C,n),a(e,ne,n),a(e,P,n),a(e,ae,n),a(e,L,n),a(e,ie,n),a(e,M,n),a(e,se,n),a(e,d,n),u(d,x),u(x,X),Ae($,X,null),u(d,Ie),u(d,J),a(e,re,n),a(e,y,n),a(e,le,n),a(e,H,n),a(e,oe,n),a(e,z,n),a(e,pe,n),a(e,A,n),a(e,ue,n),a(e,q,n),a(e,me,n),a(e,c,n),u(c,w),u(w,Y),Ae(E,Y,null),u(c,Fe),u(c,W),a(e,he,n),a(e,k,n),a(e,fe,n),a(e,S,n),a(e,de,n),a(e,N,n),a(e,ce,n),a(e,j,n),a(e,ge,n),a(e,I,n),a(e,ve,n),a(e,F,n),a(e,xe,n),a(e,g,n),u(g,_),u(_,Z),Ae(U,Z,null),u(g,Ue),u(g,K),a(e,ye,n),a(e,b,n),a(e,we,n),a(e,D,n),a(e,ke,n),a(e,G,n),a(e,_e,n),a(e,O,n),a(e,be,n),a(e,V,n),a(e,Te,n),a(e,B,n),Ce=!0},p:_t,i(e){Ce||(qe(T.$$.fragment,e),qe($.$$.fragment,e),qe(E.$$.fragment,e),qe(U.$$.fragment,e),Ce=!0)},o(e){Ee(T.$$.fragment,e),Ee($.$$.fragment,e),Ee(E.$$.fragment,e),Ee(U.$$.fragment,e),Ce=!1},d(e){e&&(t(ee),t(f),t(te),t(C),t(ne),t(P),t(ae),t(L),t(ie),t(M),t(se),t(d),t(re),t(y),t(le),t(H),t(oe),t(z),t(pe),t(A),t(ue),t(q),t(me),t(c),t(he),t(k),t(fe),t(S),t(de),t(N),t(ce),t(j),t(ge),t(I),t(ve),t(F),t(xe),t(g),t(ye),t(b),t(we),t(D),t(ke),t(G),t(_e),t(O),t(be),t(V),t(Te),t(B)),t(h),Se(T),Se($),Se(E),Se(U)}}}const Mt={local:"prompting",sections:[{local:"prompt-tuning",title:"Prompt tuning"},{local:"prefix-tuning",title:"Prefix tuning"},{local:"ptuning",title:"P-tuning"}],title:"Prompting"};function $t(De){return bt(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class qt extends Tt{constructor(h){super(),Ct(this,h,$t,Lt,kt,{})}}export{qt as component};
